@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 """Unit test for ydiff"""
@@ -13,61 +13,6 @@ sys.path.insert(0, '')
 import ydiff  # nopep8
 
 
-class Sequential(object):
-    """A non-seekable iterator, mock of file object"""
-
-    def __init__(self, items):
-        self._items = items
-        self._index = 0
-
-    def __iter__(self):
-        while True:
-            try:
-                item = self._items[self._index]
-            except IndexError:
-                raise StopIteration
-            yield item
-            self._index += 1
-
-    def readline(self):
-        try:
-            item = self._items[self._index]
-        except IndexError:
-            return ''
-        self._index += 1
-        return item
-
-
-class PatchStreamTest(unittest.TestCase):
-
-    def test_is_empty(self):
-        stream = ydiff.PatchStream(Sequential([]))
-        self.assertTrue(stream.is_empty())
-
-        stream = ydiff.PatchStream(Sequential(['hello', 'world']))
-        self.assertFalse(stream.is_empty())
-
-    def test_read_stream_header(self):
-        stream = ydiff.PatchStream(Sequential([]))
-        self.assertEqual(stream.read_stream_header(1), [])
-
-        items = ['hello', 'world', 'again']
-
-        stream = ydiff.PatchStream(Sequential(items))
-        self.assertEqual(stream.read_stream_header(2), items[:2])
-
-        stream = ydiff.PatchStream(Sequential(items))
-        self.assertEqual(stream.read_stream_header(4), items[:])
-
-    def test_iter_after_read_stream_header(self):
-        items = ['hello', 'world', 'again', 'and', 'again']
-        stream = ydiff.PatchStream(Sequential(items))
-
-        _ = stream.read_stream_header(2)
-        out = list(stream)
-        self.assertEqual(out, items)
-
-
 class DecodeTest(unittest.TestCase):
 
     def test_normal(self):
@@ -510,47 +455,6 @@ class UnifiedDiffTest(unittest.TestCase):
 
 class DiffParserTest(unittest.TestCase):
 
-    def test_type_detect_unified(self):
-        patch = """\
-spam
---- a
-+++ b
-@@ -1,2 +1,2 @@
-"""
-        items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
-        parser = ydiff.DiffParser(stream)
-        self.assertEqual(parser._type, 'unified')
-
-    @unittest.skipIf(os.name == 'nt', 'patchutils (filterdiff) unavailable')
-    def test_type_detect_context(self):
-        patch = """\
-*** /path/to/original timestamp
---- /path/to/new timestamp
-***************
-*** 1,1 ****
---- 1,2 ----
-+ This is an important
-  This part of the
-"""
-        items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
-        parser = ydiff.DiffParser(stream)
-        self.assertEqual(parser._type, 'context')
-
-    def test_type_detect_neg(self):
-        patch = """\
-spam
---- a
-spam
-+++ b
-
-"""
-        items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
-        parser = ydiff.DiffParser(stream)
-        self.assertEqual(parser._type, 'unified')
-
     def test_parse_invalid_hunk_meta(self):
         patch = """\
 spam
@@ -560,7 +464,7 @@ spam
 @@ -a,a +0 @@
 """
         items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
+        stream = iter(items)
         parser = ydiff.DiffParser(stream)
         self.assertRaises(RuntimeError, list, parser.get_diff_generator())
 
@@ -575,7 +479,7 @@ spam
 spam
 """
         items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
+        stream = iter(items)
         parser = ydiff.DiffParser(stream)
 
         out = list(parser.get_diff_generator())
@@ -597,7 +501,7 @@ spam
 --- c
 """
         items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
+        stream = iter(items)
         parser = ydiff.DiffParser(stream)
         self.assertRaises(AssertionError, list, parser.get_diff_generator())
 
@@ -613,7 +517,7 @@ spam
 +++ d
 """
         items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
+        stream = iter(items)
         parser = ydiff.DiffParser(stream)
 
         out = list(parser.get_diff_generator())
@@ -636,7 +540,7 @@ spam
 @@ -1,2 +1,2 @@
 """
         items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
+        stream = iter(items)
         parser = ydiff.DiffParser(stream)
         self.assertRaises(AssertionError, list, parser.get_diff_generator())
 
@@ -657,7 +561,7 @@ Only in foo: foo
  common
 """
         items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
+        stream = iter(items)
         parser = ydiff.DiffParser(stream)
 
         out = list(parser.get_diff_generator())
@@ -678,7 +582,7 @@ Only in foo: foo
 Only in foo: foo
 """
         items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
+        stream = iter(items)
         parser = ydiff.DiffParser(stream)
 
         out = list(parser.get_diff_generator())
@@ -703,7 +607,7 @@ Binary files a/1.pdf and b/1.pdf differ
  common
 """
         items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
+        stream = iter(items)
         parser = ydiff.DiffParser(stream)
 
         out = list(parser.get_diff_generator())
@@ -739,7 +643,7 @@ index 529e8a3..ad71921 100755
  common
 """
         items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
+        stream = iter(items)
         parser = ydiff.DiffParser(stream)
 
         out = list(parser.get_diff_generator())
@@ -765,7 +669,7 @@ Added: svn:keywords
 +Id
 """
         items = patch.splitlines(True)
-        stream = ydiff.PatchStream(Sequential(items))
+        stream = iter(items)
         parser = ydiff.DiffParser(stream)
         out = list(parser.get_diff_generator())
         self.assertEqual(len(out), 1)
